######################
This project is made for educational and entertainment purposes only
I (David H Peterson) do not own the rights to the original game, aka "Battleship"
######################

To play the game, please type the following into a python source file:

######################
import battleship
battleship.startup()
battleship.game()
######################

There, now you can play battleship in the terminal!